/*  $Id: ARunnableSet.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;


import java.util.Vector;

/** 
 * Runnable made of several other runnable.
 */
public abstract class ARunnableSet implements Runnable
{
	/** 
	 * Create new runnable set
	 */
	public ARunnableSet()
	{
		_runList=new Vector<Runnable>();
	}
	/** 
	 * Add a runnable to this set.
	 * Of course, runnable must be added before running this set.
	 * @param run runnable to add.
	 */ 
	public void Add(Runnable run) 
	{
		_runList.add(run);
	}
	/** 
	 * Inner runnable list. 
	 * @djin.relation aggregation,1,*,Runnable
	 */ 
	private Vector<Runnable> _runList;
	/** 
	 * Gets all added runnable to this set.
	 * Helper getter to let subclasses access to the set content.
	 * @return the runnable list.
	 */
	protected Vector<Runnable> getRunList()
	{
		return _runList;
	}
	/**
	 * Runnable interface implementation.
	 * All subclass must override this method to define
	 * how all runnables in run list are chained.
	 */
	public abstract void run();
}
